@@ -141,16 +141,23 @@ class BHunters(Karton):
         headers = {
             "Content-Type": "application/json"
         }
-        response = requests.post(webhook_url, data=json.dumps(data), headers=headers)
-        
+        trials=5
+        while trials>0:
+            try:
+                response = requests.post(webhook_url, data=json.dumps(data), headers=headers)
+                break
+            except Exception as e:
+                trials-=1
+                if trials>0:
+                    time.sleep(10)
     def checkjs(self,url):
         try:
             response = requests.get(url,timeout=10)
-            if response.headers["Content-Type"].startswith("application/javascript"):
+            if "Content-Type" in response.headers and response.headers["Content-Type"].startswith("application/javascript"):
                 return True
             else:
                 return False
-        except requests.exceptions.RequestException:
+        except Exception as e:
             return False
 
     def monogocon(self):
